@@ -875,13 +875,15 @@ def eval_model_type(modelDir):
 
   """
 
-  if os.path.isfile(modelDir+"/ProDiMo_01.out") or os.path.isfile(modelDir+"/ProDiMo_001.out"):
+  if os.path.isfile(modelDir+"/ProDiMo_01.out") or \
+     os.path.isfile(modelDir+"/ProDiMo_001.out") or \
+     os.path.isfile(modelDir+"/ProDiMo_0001.out") or \
+     os.path.isfile(modelDir+"/ProDiMo_00001.out"):
     mtype="prodimoTD"
-
   elif os.path.isfile(modelDir+"/Molecular_Cloud_Input.in"):
     mtype="mc"
   else:
-      mtype="prodimo"
+    mtype="prodimo"
 
   return mtype
 
