@@ -425,7 +425,7 @@ def plot_spectra(dat, normalise = False, fig=None, ax=None, overplot=False, add=
                 add_flux=d.convNLTEflux
             else:
                 add_flux=d.convLTEflux
-            fig_list[0],ax_list[0] = _basic_spectra_plot(add_wave, add_flux,convR= dat[0].convR,sampling=sampling, scaling=scaling_list[i], offset=offset_list[i],  normalise=normalise, fig=fig_list[0], ax=ax_list[0], style=style, figsize=figsize, label=label_list[i], color=color_list[i],lw=lw, where='mid')
+            fig_list[0],ax_list[0] = _basic_spectra_plot(add_wave, add_flux,convR= dat[i].convR,sampling=sampling, scaling=scaling_list[i], offset=offset_list[i],  normalise=normalise, fig=fig_list[0], ax=ax_list[0], style=style, figsize=figsize, label=label_list[i], color=color_list[i],lw=lw, where='mid')
         return(fig_list[0],ax_list[0])
     else:
         for i,d in enumerate(dat):
@@ -434,7 +434,7 @@ def plot_spectra(dat, normalise = False, fig=None, ax=None, overplot=False, add=
                 add_flux=d.convNLTEflux
             else:
                 add_flux=d.convLTEflux
-            fig_list[i],ax_list[i] = _basic_spectra_plot(add_wave, add_flux,convR= dat[0].convR,sampling=sampling, scaling=scaling_list[i], offset=offset_list[i],  normalise=normalise, fig=fig_list[i], ax=ax_list[i], style=style, figsize=figsize, label=label_list[i], color=color_list[i],lw=lw, where='mid')
+            fig_list[i],ax_list[i] = _basic_spectra_plot(add_wave, add_flux,convR= dat[i].convR,sampling=sampling, scaling=scaling_list[i], offset=offset_list[i],  normalise=normalise, fig=fig_list[i], ax=ax_list[i], style=style, figsize=figsize, label=label_list[i], color=color_list[i],lw=lw, where='mid')
         if axx_len>1:
             return(fig_list[0],np.array(ax_list))
         else:
