@@ -38,10 +38,14 @@ def load_mplstyle(stylename):
 
 def set_param(paramFileList,param,value):
   """
-
   Utility function that allows to change ProDiMo parameter values in a list
   of ProDiMo Parameters (e.g. read in from Parameter.in)
 
+  If the parameter is not found in the file it will append it at the end of the
+  file.
+
+  If `value==DELETEPARAM` the routine will delete he line containing that parameter.
+
   This routine cannot deal yet with complex parameter structures. Only works
   with parameters that have a single value.
 
@@ -52,12 +56,14 @@ def set_param(paramFileList,param,value):
     You can get it via `f.readLines()`
     This can also be a list that already includes changed parameters.
     Each entry in the list should correspond to one Parameter.
+    Please note this input will be changed directly (i.e. the list is not copied).
 
   param : str
-    The ProDiMo Parameter name (without the ! )
+    The ProDiMo parameter name (including the ! )
 
   value : str
-    the Parameter value. The string will be use as is.
+    the parameter value. The string will be used as is.
+    If value is `"DELETEPARAM"` the parameter will be deleted.
     There are no checks or anything.
 
 
@@ -66,9 +72,23 @@ def set_param(paramFileList,param,value):
   list
     the paramFileList
 
+  _todo: This is quick and dirty ... maybe it is worth to make this more elegant and more flexible (e.g. its own class, allow to set comments etc.)
+
   """
+
+  # delete the parameter
+  if value.strip()=="DELETEPARAM":
+    for i in range(len(paramFileList)):
+      if paramFileList[i].find(param)>-1:
+        print("delete line : "+paramFileList[i])
+        paramFileList.pop(i)
+        return paramFileList
+    print("Parameter '"+param+"' not found.")
+    return paramFileList
+
   replaced=False
   for i in range(len(paramFileList)):
+    # FIXME shouln"t that be `"! "+param
     ip=paramFileList[i].find(param)
     if ip>-1:
       val=paramFileList[i][0:ip-1]
@@ -81,7 +101,7 @@ def set_param(paramFileList,param,value):
         newval=value+"  "
       else:
         newval=value+" "
-      print(val,rest,lval,lnewval,newval)
+      # print(val,rest,lval,lnewval,newval)
 
       paramFileList[i]=newval+rest
       print("change : ",paramFileList[i])
