@@ -611,7 +611,10 @@ class LinePP(_PostProcess):
     print("momentmap moment "+str(moment)+" ...")
 
     outfile=outfits.replace(".fits",".im")
-    ct.immoments(infits,outfile=outfile,moments=[moment],**immomentsparams)
+    if immomentsparams is not None:
+      ct.immoments(infits,outfile=outfile,moments=[moment],**immomentsparams)
+    else:
+      ct.immoments(infits,outfile=outfile,moments=[moment])
 
     ct.exportfits(fitsimage=outfits,imagename=outfile,dropdeg=True,overwrite=True)
 
